Module api

Module api 

Structs

Document
Central instance to access all Document related resource activities
GoogleCloudDocumentaiV1Barcode
Encodes the detailed information of a barcode.
GoogleCloudDocumentaiV1BatchDocumentsInputConfig
The common config to specify a set of documents used as input.
GoogleCloudDocumentaiV1BatchProcessRequest
Request message for BatchProcessDocuments.
GoogleCloudDocumentaiV1BoundingPoly
A bounding polygon for the detected image annotation.
GoogleCloudDocumentaiV1DeployProcessorVersionRequest
Request message for the DeployProcessorVersion method.
GoogleCloudDocumentaiV1DisableProcessorRequest
Request message for the DisableProcessor method.
GoogleCloudDocumentaiV1Document
Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality.
GoogleCloudDocumentaiV1DocumentChunkedDocument
Represents the chunks that the document is divided into.
GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk
Represents a chunk.
GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter
Represents the page footer associated with the chunk.
GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageHeader
Represents the page header associated with the chunk.
GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageSpan
Represents where the chunk starts and ends in the document.
GoogleCloudDocumentaiV1DocumentDocumentLayout
Represents the parsed layout of a document as a collection of blocks that the document is divided into.
GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock
Represents a block. A block could be one of the various types (text, table, list) supported.
GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock
Represents a list type block.
GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListEntry
Represents an entry in the list.
GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan
Represents where the block starts and ends in the document.
GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock
Represents a table type block.
GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableCell
Represents a cell in a table row.
GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableRow
Represents a row in a table.
GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock
Represents a text type block.
GoogleCloudDocumentaiV1DocumentEntitiesRevision
Entity revision.
GoogleCloudDocumentaiV1DocumentEntity
An entity that could be a phrase in the text or a property that belongs to the document. It is a known entity type, such as a person, an organization, or location.
GoogleCloudDocumentaiV1DocumentEntityNormalizedValue
Parsed and normalized entity value.
GoogleCloudDocumentaiV1DocumentEntityRelation
Relationship between Entities.
GoogleCloudDocumentaiV1DocumentEntityValidationOutput
The output of the validation given the document and the validation rules.
GoogleCloudDocumentaiV1DocumentEntityValidationOutputValidationResult
Validation result for a single validation rule.
GoogleCloudDocumentaiV1DocumentOutputConfig
Config that controls the output of documents. All documents will be written as a JSON file.
GoogleCloudDocumentaiV1DocumentOutputConfigGcsOutputConfig
The configuration used when outputting documents.
GoogleCloudDocumentaiV1DocumentOutputConfigGcsOutputConfigShardingConfig
The sharding config for the output document.
GoogleCloudDocumentaiV1DocumentPage
A page in a Document.
GoogleCloudDocumentaiV1DocumentPageAnchor
Referencing the visual context of the entity in the Document.pages. Page anchors can be cross-page, consist of multiple bounding polygons and optionally reference specific layout element types.
GoogleCloudDocumentaiV1DocumentPageAnchorPageRef
Represents a weak reference to a page element within a document.
GoogleCloudDocumentaiV1DocumentPageBlock
A block has a set of lines (collected into paragraphs) that have a common line-spacing and orientation.
GoogleCloudDocumentaiV1DocumentPageDetectedBarcode
A detected barcode.
GoogleCloudDocumentaiV1DocumentPageDetectedLanguage
Detected language for a structural component.
GoogleCloudDocumentaiV1DocumentPageDimension
Dimension for the page.
GoogleCloudDocumentaiV1DocumentPageFormField
A form field detected on the page.
GoogleCloudDocumentaiV1DocumentPageImage
Rendered image contents for this page.
GoogleCloudDocumentaiV1DocumentPageImageQualityScores
Image quality scores for the page image.
GoogleCloudDocumentaiV1DocumentPageImageQualityScoresDetectedDefect
Image Quality Defects
GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
GoogleCloudDocumentaiV1DocumentPageLine
A collection of tokens that a human would perceive as a line. Does not cross column boundaries, can be horizontal, vertical, etc.
GoogleCloudDocumentaiV1DocumentPageMatrix
Representation for transformation matrix, intended to be compatible and used with OpenCV format for image manipulation.
GoogleCloudDocumentaiV1DocumentPageParagraph
A collection of lines that a human would perceive as a paragraph.
GoogleCloudDocumentaiV1DocumentPageSymbol
A detected symbol.
GoogleCloudDocumentaiV1DocumentPageTable
A table representation similar to HTML table structure.
GoogleCloudDocumentaiV1DocumentPageTableTableCell
A cell representation inside the table.
GoogleCloudDocumentaiV1DocumentPageTableTableRow
A row of table cells.
GoogleCloudDocumentaiV1DocumentPageToken
A detected token.
GoogleCloudDocumentaiV1DocumentPageTokenDetectedBreak
Detected break at the end of a Token.
GoogleCloudDocumentaiV1DocumentPageTokenStyleInfo
Font and other text style attributes.
GoogleCloudDocumentaiV1DocumentPageVisualElement
Detected non-text visual elements e.g. checkbox, signature etc. on the page.
GoogleCloudDocumentaiV1DocumentProvenance
Structure to identify provenance relationships between annotations in different revisions.
GoogleCloudDocumentaiV1DocumentProvenanceParent
The parent element the current element is based on. Used for referencing/aligning, removal and replacement operations.
GoogleCloudDocumentaiV1DocumentRevision
Contains past or forward revisions of this document.
GoogleCloudDocumentaiV1DocumentRevisionHumanReview
Human Review information of the document.
GoogleCloudDocumentaiV1DocumentSchema
The schema defines the output of the processed document by a processor.
GoogleCloudDocumentaiV1DocumentSchemaEntityType
EntityType is the wrapper of a label of the corresponding model with detailed attributes and limitations for entity-based processors. Multiple types can also compose a dependency tree to represent nested types.
GoogleCloudDocumentaiV1DocumentSchemaEntityTypeEnumValues
Defines the a list of enum values.
GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty
Defines properties that can be part of the entity type.
GoogleCloudDocumentaiV1DocumentSchemaMetadata
Metadata for global schema behavior.
GoogleCloudDocumentaiV1DocumentShardInfo
For a large document, sharding may be performed to produce several document shards. Each document shard contains this field to detail which shard it is.
GoogleCloudDocumentaiV1DocumentStyle
Annotation for common text style attributes. This adheres to CSS conventions as much as possible.
GoogleCloudDocumentaiV1DocumentStyleFontSize
Font size with unit.
GoogleCloudDocumentaiV1DocumentTextAnchor
Text reference indexing into the Document.text.
GoogleCloudDocumentaiV1DocumentTextAnchorTextSegment
A text segment in the Document.text. The indices may be out of bounds which indicate that the text extends into another document shard for large sharded documents. See ShardInfo.text_offset
GoogleCloudDocumentaiV1DocumentTextChange
This message is used for text changes aka. OCR corrections.
GoogleCloudDocumentaiV1Documents
A set of inline documents.
GoogleCloudDocumentaiV1EnableProcessorRequest
Request message for the EnableProcessor method.
GoogleCloudDocumentaiV1EvaluateProcessorVersionRequest
Evaluates the given ProcessorVersion against the supplied documents.
GoogleCloudDocumentaiV1Evaluation
An evaluation of a ProcessorVersion’s performance.
GoogleCloudDocumentaiV1EvaluationConfidenceLevelMetrics
Evaluations metrics, at a specific confidence level.
GoogleCloudDocumentaiV1EvaluationCounters
Evaluation counters for the documents that were used.
GoogleCloudDocumentaiV1EvaluationMetrics
Evaluation metrics, either in aggregate or about a specific entity.
GoogleCloudDocumentaiV1EvaluationMultiConfidenceMetrics
Metrics across multiple confidence levels.
GoogleCloudDocumentaiV1EvaluationReference
Gives a short summary of an evaluation, and links to the evaluation itself.
GoogleCloudDocumentaiV1FetchProcessorTypesResponse
Response message for the FetchProcessorTypes method.
GoogleCloudDocumentaiV1GcsDocument
Specifies a document stored on Cloud Storage.
GoogleCloudDocumentaiV1GcsDocuments
Specifies a set of documents on Cloud Storage.
GoogleCloudDocumentaiV1GcsPrefix
Specifies all documents on Cloud Storage with a common prefix.
GoogleCloudDocumentaiV1GenerateSchemaVersionRequest
Request message for GenerateSchemaVersion.
GoogleCloudDocumentaiV1GenerateSchemaVersionRequestGenerateSchemaVersionParams
The parameters for the schema generation.
GoogleCloudDocumentaiV1GenerateSchemaVersionResponse
Response message for GenerateSchemaVersion.
GoogleCloudDocumentaiV1HumanReviewStatus
The status of human review on a processed document.
GoogleCloudDocumentaiV1ListEvaluationsResponse
The response from ListEvaluations.
GoogleCloudDocumentaiV1ListProcessorTypesResponse
Response message for the ListProcessorTypes method.
GoogleCloudDocumentaiV1ListProcessorVersionsResponse
Response message for the ListProcessorVersions method.
GoogleCloudDocumentaiV1ListProcessorsResponse
Response message for the ListProcessors method.
GoogleCloudDocumentaiV1ListSchemaVersionsResponse
Response message for ListSchemaVersions.
GoogleCloudDocumentaiV1ListSchemasResponse
Response message for ListSchemas.
GoogleCloudDocumentaiV1NextSchema
NextSchema is a collection of SchemaVersions.
GoogleCloudDocumentaiV1NormalizedVertex
A vertex represents a 2D point in the image. NOTE: the normalized vertex coordinates are relative to the original image and range from 0 to 1.
GoogleCloudDocumentaiV1OcrConfig
Config for Document OCR.
GoogleCloudDocumentaiV1OcrConfigHints
Hints for OCR Engine
GoogleCloudDocumentaiV1OcrConfigPremiumFeatures
Configurations for premium OCR features.
GoogleCloudDocumentaiV1ProcessOptions
Options for Process API
GoogleCloudDocumentaiV1ProcessOptionsIndividualPageSelector
A list of individual page numbers.
GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig
Serving config for layout parser processor.
GoogleCloudDocumentaiV1ProcessOptionsLayoutConfigChunkingConfig
Serving config for chunking.
GoogleCloudDocumentaiV1ProcessRequest
Request message for the ProcessDocument method.
GoogleCloudDocumentaiV1ProcessResponse
Response message for the ProcessDocument method.
GoogleCloudDocumentaiV1Processor
The first-class citizen for Document AI. Each processor defines how to extract structural information from a document.
GoogleCloudDocumentaiV1ProcessorType
A processor type is responsible for performing a certain document understanding task on a certain type of document.
GoogleCloudDocumentaiV1ProcessorTypeLocationInfo
The location information about where the processor is available.
GoogleCloudDocumentaiV1ProcessorVersion
A processor version is an implementation of a processor. Each processor can have multiple versions, pretrained by Google internally or uptrained by the customer. A processor can only have one default version at a time. Its document-processing behavior is defined by that version.
GoogleCloudDocumentaiV1ProcessorVersionAlias
Contains the alias and the aliased resource name of processor version.
GoogleCloudDocumentaiV1ProcessorVersionDeprecationInfo
Information about the upcoming deprecation of this processor version.
GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo
Information about Generative AI model-based processor versions.
GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfoCustomGenAiModelInfo
Information for a custom Generative AI model created by the user. These are created with Create New Version in either the Call foundation model or Fine tuning tabs.
GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo
Information for a pretrained Google-managed foundation model.
GoogleCloudDocumentaiV1RawDocument
Payload message of raw document content (bytes).
GoogleCloudDocumentaiV1RawDocuments
Specifies a set of raw documents.
GoogleCloudDocumentaiV1ReviewDocumentRequest
Request message for the ReviewDocument method.
GoogleCloudDocumentaiV1SchemaGenerationHistory
The history of schema generation iterations.
GoogleCloudDocumentaiV1SchemaGenerationIteration
A single iteration of the schema generation.
GoogleCloudDocumentaiV1SchemaVersion
SchemaVersion is a version of the Schema which is created in SchemaGroup.
GoogleCloudDocumentaiV1SetDefaultProcessorVersionRequest
Request message for the SetDefaultProcessorVersion method.
GoogleCloudDocumentaiV1TrainProcessorVersionRequest
Request message for the TrainProcessorVersion method.
GoogleCloudDocumentaiV1TrainProcessorVersionRequestCustomDocumentExtractionOptions
Options to control the training of the Custom Document Extraction (CDE) Processor.
GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions
Options to control foundation model tuning of the processor.
GoogleCloudDocumentaiV1TrainProcessorVersionRequestInputData
The input data used to train a new ProcessorVersion.
GoogleCloudDocumentaiV1UndeployProcessorVersionRequest
Request message for the UndeployProcessorVersion method.
GoogleCloudDocumentaiV1Vertex
A vertex represents a 2D point in the image. NOTE: the vertex coordinates are in the same scale as the original image.
GoogleCloudLocationListLocationsResponse
The response message for Locations.ListLocations.
GoogleCloudLocationLocation
A resource that represents a Google Cloud location.
GoogleLongrunningListOperationsResponse
The response message for Operations.ListOperations.
GoogleLongrunningOperation
This resource represents a long-running operation that is the result of a network API call.
GoogleProtobufEmpty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }
GoogleRpcStatus
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.
GoogleTypeColor
Represents a color in the RGBA color space. This representation is designed for simplicity of conversion to and from color representations in various languages over compactness. For example, the fields of this representation can be trivially provided to the constructor of java.awt.Color in Java; it can also be trivially provided to UIColor’s +colorWithRed:green:blue:alpha method in iOS; and, with just a little work, it can be easily formatted into a CSS rgba() string in JavaScript. This reference page doesn’t have information about the absolute color space that should be used to interpret the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default, applications should assume the sRGB color space. When color equality needs to be decided, implementations, unless documented otherwise, treat two colors as equal if all their red, green, blue, and alpha values each differ by at most 1e-5. Example (Java): import com.google.type.Color; // … public static java.awt.Color fromProto(Color protocolor) { float alpha = protocolor.hasAlpha() ? protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); } public static Color toProto(java.awt.Color color) { float red = (float) color.getRed(); float green = (float) color.getGreen(); float blue = (float) color.getBlue(); float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue / denominator); int alpha = color.getAlpha(); if (alpha != 255) { result.setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .build()); } return resultBuilder.build(); } // … Example (iOS / Obj-C): // … static UIColor* fromProto(Color* protocolor) { float red = [protocolor red]; float green = [protocolor green]; float blue = [protocolor blue]; FloatValue* alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper != nil) { alpha = [alpha_wrapper value]; } return [UIColor colorWithRed:red green:green blue:blue alpha:alpha]; } static Color* toProto(UIColor* color) { CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&blue alpha:&alpha]) { return nil; } Color* result = [[Color alloc] init]; [result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <= 0.9999) { [result setAlpha:floatWrapperWithValue(alpha)]; } [result autorelease]; return result; } // … Example (JavaScript): // … var protoToCssColor = function(rgb_color) { var redFrac = rgb_color.red || 0.0; var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0; var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255); var blue = Math.floor(blueFrac * 255); if (!(‘alpha’ in rgb_color)) { return rgbToCssColor(red, green, blue); } var alphaFrac = rgb_color.alpha.value || 0.0; var rgbParams = [red, green, blue].join(‘,’); return [‘rgba(’, rgbParams, ‘,’, alphaFrac, ‘)’].join(‘’); }; var rgbToCssColor = function(red, green, blue) { var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString = rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var resultBuilder = [‘#’]; for (var i = 0; i < missingZeros; i++) { resultBuilder.push(‘0’); } resultBuilder.push(hexString); return resultBuilder.join(‘’); }; // …
GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type.TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
GoogleTypeDateTime
Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways: * When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC. * When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone. * When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user’s timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application’s limitations.
GoogleTypeMoney
Represents an amount of money with its currency type.
GoogleTypePostalAddress
Represents a postal address, such as for postal delivery or payments addresses. With a postal address, a postal service can deliver items to a premise, P.O. box, or similar. A postal address is not intended to model geographical locations like roads, towns, or mountains. In typical usage, an address would be created by user input or from importing existing data, depending on the type of process. Advice on address input or editing: - Use an internationalization-ready address widget such as https://github.com/google/libaddressinput. - Users should not be presented with UI elements for input or editing of fields outside countries where that field is used. For more guidance on how to use this schema, see: https://support.google.com/business/answer/6397478.
GoogleTypeTimeZone
Represents a time zone from the IANA Time Zone Database.
OperationDeleteCall
Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn’t support this method, it returns google.rpc.Code.UNIMPLEMENTED.
OperationMethods
A builder providing access to all methods supported on operation resources. It is not used directly, but through the Document hub.
ProjectLocationFetchProcessorTypeCall
Fetches processor types. Note that we don’t use ListProcessorTypes here, because it isn’t paginated.
ProjectLocationGetCall
Gets information about a location.
ProjectLocationListCall
Lists information about the supported locations for this service.
ProjectLocationOperationCancelCall
Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn’t support this method, it returns google.rpc.Code.UNIMPLEMENTED. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED.
ProjectLocationOperationGetCall
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
ProjectLocationOperationListCall
Lists operations that match the specified filter in the request. If the server doesn’t support this method, it returns UNIMPLEMENTED.
ProjectLocationProcessorBatchProcesCall
LRO endpoint to batch process many documents. The output is written to Cloud Storage as JSON in the Document format.
ProjectLocationProcessorCreateCall
Creates a processor from the ProcessorType provided. The processor will be at ENABLED state by default after its creation. Note that this method requires the documentai.processors.create permission on the project, which is highly privileged. A user or service account with this permission can create new processors that can interact with any gcs bucket in your project.
ProjectLocationProcessorDeleteCall
Deletes the processor, unloads all deployed model artifacts if it was enabled and then deletes all artifacts associated with this processor.
ProjectLocationProcessorDisableCall
Disables a processor
ProjectLocationProcessorEnableCall
Enables a processor
ProjectLocationProcessorGetCall
Gets a processor detail.
ProjectLocationProcessorHumanReviewConfigReviewDocumentCall
Send a document for Human Review. The input document should be processed by the specified processor.
ProjectLocationProcessorListCall
Lists all processors which belong to this project.
ProjectLocationProcessorProcesCall
Processes a single document.
ProjectLocationProcessorProcessorVersionBatchProcesCall
LRO endpoint to batch process many documents. The output is written to Cloud Storage as JSON in the Document format.
ProjectLocationProcessorProcessorVersionDeleteCall
Deletes the processor version, all artifacts under the processor version will be deleted.
ProjectLocationProcessorProcessorVersionDeployCall
Deploys the processor version.
ProjectLocationProcessorProcessorVersionEvaluateProcessorVersionCall
Evaluates a ProcessorVersion against annotated documents, producing an Evaluation.
ProjectLocationProcessorProcessorVersionEvaluationGetCall
Retrieves a specific evaluation.
ProjectLocationProcessorProcessorVersionEvaluationListCall
Retrieves a set of evaluations for a given processor version.
ProjectLocationProcessorProcessorVersionGetCall
Gets a processor version detail.
ProjectLocationProcessorProcessorVersionListCall
Lists all versions of a processor.
ProjectLocationProcessorProcessorVersionProcesCall
Processes a single document.
ProjectLocationProcessorProcessorVersionTrainCall
Trains a new processor version. Operation metadata is returned as TrainProcessorVersionMetadata.
ProjectLocationProcessorProcessorVersionUndeployCall
Undeploys the processor version.
ProjectLocationProcessorSetDefaultProcessorVersionCall
Set the default (active) version of a Processor that will be used in ProcessDocument and BatchProcessDocuments.
ProjectLocationProcessorTypeGetCall
Gets a processor type detail.
ProjectLocationProcessorTypeListCall
Lists the processor types that exist.
ProjectLocationSchemaCreateCall
Creates a schema.
ProjectLocationSchemaDeleteCall
Deletes a schema.
ProjectLocationSchemaGetCall
Gets a schema.
ProjectLocationSchemaListCall
Lists Schemas.
ProjectLocationSchemaPatchCall
Updates a schema. Editable fields are: - display_name - labels
ProjectLocationSchemaSchemaVersionCreateCall
Creates a schema version.
ProjectLocationSchemaSchemaVersionDeleteCall
Deletes a schema version.
ProjectLocationSchemaSchemaVersionGenerateCall
Generates a schema version.
ProjectLocationSchemaSchemaVersionGetCall
Gets a schema version.
ProjectLocationSchemaSchemaVersionListCall
Lists SchemaVersions.
ProjectLocationSchemaSchemaVersionPatchCall
Updates a schema version. Editable fields are: - display_name - labels
ProjectMethods
A builder providing access to all methods supported on project resources. It is not used directly, but through the Document hub.
ProjectOperationGetCall
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.

Enums

Scope
Identifies the an OAuth2 authorization scope. A scope is needed when requesting an authorization token.