GoogleCloudDocumentaiV1BatchProcessRequest

Struct GoogleCloudDocumentaiV1BatchProcessRequest 

pub struct GoogleCloudDocumentaiV1BatchProcessRequest {
    pub document_output_config: Option<GoogleCloudDocumentaiV1DocumentOutputConfig>,
    pub input_documents: Option<GoogleCloudDocumentaiV1BatchDocumentsInputConfig>,
    pub labels: Option<HashMap<String, String>>,
    pub process_options: Option<GoogleCloudDocumentaiV1ProcessOptions>,
    pub skip_human_review: Option<bool>,
}
Request message for BatchProcessDocuments.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

document_output_config: Option<GoogleCloudDocumentaiV1DocumentOutputConfig>

The output configuration for the BatchProcessDocuments method.

input_documents: Option<GoogleCloudDocumentaiV1BatchDocumentsInputConfig>

The input documents for the BatchProcessDocuments method.

labels: Option<HashMap<String, String>>

Optional. The labels with user-defined metadata for the request. Label keys and values can be no longer than 63 characters (Unicode codepoints) and can only contain lowercase letters, numeric characters, underscores, and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter.

process_options: Option<GoogleCloudDocumentaiV1ProcessOptions>

Inference-time options for the process API

skip_human_review: Option<bool>

Whether human review should be skipped for this request. Default to false.