pub struct GoogleCloudDocumentaiV1GenerateSchemaVersionResponse {
pub schema_version: Option<GoogleCloudDocumentaiV1SchemaVersion>,
}Expand description
Response message for GenerateSchemaVersion.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
schema_version: Option<GoogleCloudDocumentaiV1SchemaVersion>The schema version generated by the model.