pub struct GoogleCloudDocumentaiV1ListProcessorsResponse {
pub next_page_token: Option<String>,
pub processors: Option<Vec<GoogleCloudDocumentaiV1Processor>>,
}Expand description
Response message for the ListProcessors method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations processors list projects (response)
Fields
next_page_token: Option<String>Points to the next processor, otherwise empty.
processors: Option<Vec<GoogleCloudDocumentaiV1Processor>>The list of processors.