pub struct GoogleCloudDocumentaiV1ProcessRequest {
pub field_mask: Option<FieldMask>,
pub gcs_document: Option<GoogleCloudDocumentaiV1GcsDocument>,
pub imageless_mode: Option<bool>,
pub inline_document: Option<GoogleCloudDocumentaiV1Document>,
pub labels: Option<HashMap<String, String>>,
pub process_options: Option<GoogleCloudDocumentaiV1ProcessOptions>,
pub raw_document: Option<GoogleCloudDocumentaiV1RawDocument>,
pub skip_human_review: Option<bool>,
}Expand description
Request message for the ProcessDocument method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
field_mask: Option<FieldMask>Specifies which fields to include in the ProcessResponse.document output. Only supports top-level document and pages field, so it must be in the form of {document_field_name} or pages.{page_field_name}.
gcs_document: Option<GoogleCloudDocumentaiV1GcsDocument>A raw document on Google Cloud Storage.
imageless_mode: Option<bool>Optional. Option to remove images from the document.
inline_document: Option<GoogleCloudDocumentaiV1Document>An inline document proto.
labels: Option<HashMap<String, String>>Optional. The labels with user-defined metadata for the request. Label keys and values can be no longer than 63 characters (Unicode codepoints) and can only contain lowercase letters, numeric characters, underscores, and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter.
process_options: Option<GoogleCloudDocumentaiV1ProcessOptions>Inference-time options for the process API
raw_document: Option<GoogleCloudDocumentaiV1RawDocument>A raw document content (bytes).
skip_human_review: Option<bool>Whether human review should be skipped for this request. Default to false.