pub struct GoogleCloudDocumentaiV1ProcessResponse {
pub document: Option<GoogleCloudDocumentaiV1Document>,
pub human_review_status: Option<GoogleCloudDocumentaiV1HumanReviewStatus>,
}Expand description
Response message for the ProcessDocument method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
document: Option<GoogleCloudDocumentaiV1Document>The document payload, will populate fields based on the processor’s behavior.
human_review_status: Option<GoogleCloudDocumentaiV1HumanReviewStatus>The status of human review on the processed document.