pub struct GoogleCloudDocumentaiV1Processor {
pub active_schema_version: Option<String>,
pub create_time: Option<DateTime<Utc>>,
pub default_processor_version: Option<String>,
pub display_name: Option<String>,
pub kms_key_name: Option<String>,
pub name: Option<String>,
pub process_endpoint: Option<String>,
pub processor_version_aliases: Option<Vec<GoogleCloudDocumentaiV1ProcessorVersionAlias>>,
pub satisfies_pzi: Option<bool>,
pub satisfies_pzs: Option<bool>,
pub state: Option<String>,
pub type_: Option<String>,
}Expand description
The first-class citizen for Document AI. Each processor defines how to extract structural information from a document.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations processors create projects (request|response)
- locations processors get projects (response)
Fields
active_schema_version: Option<String>Optional. SchemaVersion used by the Processor. It is the same as Processor’s DatasetSchema.schema_version Format is `projects/{project}/locations/{location}/schemas/{schema}/schemaVersions/{schema_version}
create_time: Option<DateTime<Utc>>Output only. The time the processor was created.
default_processor_version: Option<String>The default processor version.
display_name: Option<String>The display name of the processor.
kms_key_name: Option<String>The KMS key used for encryption and decryption in CMEK scenarios.
name: Option<String>Output only. Immutable. The resource name of the processor. Format: projects/{project}/locations/{location}/processors/{processor}
process_endpoint: Option<String>Output only. Immutable. The http endpoint that can be called to invoke processing.
processor_version_aliases: Option<Vec<GoogleCloudDocumentaiV1ProcessorVersionAlias>>Output only. The processor version aliases.
satisfies_pzi: Option<bool>Output only. Reserved for future use.
satisfies_pzs: Option<bool>Output only. Reserved for future use.
state: Option<String>Output only. The state of the processor.
type_: Option<String>The processor type, such as: OCR_PROCESSOR, INVOICE_PROCESSOR. To get a list of processor types, see FetchProcessorTypes.