pub struct GoogleCloudDocumentaiV1ProcessorVersion {Show 14 fields
pub create_time: Option<DateTime<Utc>>,
pub deprecation_info: Option<GoogleCloudDocumentaiV1ProcessorVersionDeprecationInfo>,
pub display_name: Option<String>,
pub document_schema: Option<GoogleCloudDocumentaiV1DocumentSchema>,
pub gen_ai_model_info: Option<GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo>,
pub google_managed: Option<bool>,
pub kms_key_name: Option<String>,
pub kms_key_version_name: Option<String>,
pub latest_evaluation: Option<GoogleCloudDocumentaiV1EvaluationReference>,
pub model_type: Option<String>,
pub name: Option<String>,
pub satisfies_pzi: Option<bool>,
pub satisfies_pzs: Option<bool>,
pub state: Option<String>,
}Expand description
A processor version is an implementation of a processor. Each processor can have multiple versions, pretrained by Google internally or uptrained by the customer. A processor can only have one default version at a time. Its document-processing behavior is defined by that version.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
create_time: Option<DateTime<Utc>>Output only. The time the processor version was created.
deprecation_info: Option<GoogleCloudDocumentaiV1ProcessorVersionDeprecationInfo>Output only. If set, information about the eventual deprecation of this version.
display_name: Option<String>The display name of the processor version.
document_schema: Option<GoogleCloudDocumentaiV1DocumentSchema>Output only. The schema of the processor version. Describes the output.
gen_ai_model_info: Option<GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo>Output only. Information about Generative AI model-based processor versions.
google_managed: Option<bool>Output only. Denotes that this ProcessorVersion is managed by Google.
kms_key_name: Option<String>Output only. The KMS key name used for encryption.
kms_key_version_name: Option<String>Output only. The KMS key version with which data is encrypted.
latest_evaluation: Option<GoogleCloudDocumentaiV1EvaluationReference>Output only. The most recently invoked evaluation for the processor version.
model_type: Option<String>Output only. The model type of this processor version.
name: Option<String>Identifier. The resource name of the processor version. Format: projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processor_version}
satisfies_pzi: Option<bool>Output only. Reserved for future use.
satisfies_pzs: Option<bool>Output only. Reserved for future use.
state: Option<String>Output only. The state of the processor version.