GoogleCloudDocumentaiV1TrainProcessorVersionRequest

Struct GoogleCloudDocumentaiV1TrainProcessorVersionRequest 

pub struct GoogleCloudDocumentaiV1TrainProcessorVersionRequest {
    pub base_processor_version: Option<String>,
    pub custom_document_extraction_options: Option<GoogleCloudDocumentaiV1TrainProcessorVersionRequestCustomDocumentExtractionOptions>,
    pub document_schema: Option<GoogleCloudDocumentaiV1DocumentSchema>,
    pub foundation_model_tuning_options: Option<GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions>,
    pub input_data: Option<GoogleCloudDocumentaiV1TrainProcessorVersionRequestInputData>,
    pub processor_version: Option<GoogleCloudDocumentaiV1ProcessorVersion>,
}
Request message for the TrainProcessorVersion method.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

base_processor_version: Option<String>

Optional. The processor version to use as a base for training. This processor version must be a child of parent. Format: projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}.

custom_document_extraction_options: Option<GoogleCloudDocumentaiV1TrainProcessorVersionRequestCustomDocumentExtractionOptions>

Options to control Custom Document Extraction (CDE) Processor.

document_schema: Option<GoogleCloudDocumentaiV1DocumentSchema>

Optional. The schema the processor version will be trained with.

foundation_model_tuning_options: Option<GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions>

Options to control foundation model tuning of a processor.

input_data: Option<GoogleCloudDocumentaiV1TrainProcessorVersionRequestInputData>

Optional. The input data used to train the ProcessorVersion.

processor_version: Option<GoogleCloudDocumentaiV1ProcessorVersion>

Required. The processor version to be created.