Struct google_documentai1::api::GoogleCloudDocumentaiV1BatchProcessRequest [−][src]
Request message for batch process document method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
document_output_config: Option<GoogleCloudDocumentaiV1DocumentOutputConfig>The overall output config for batch process.
input_documents: Option<GoogleCloudDocumentaiV1BatchDocumentsInputConfig>The input documents for batch process.
skip_human_review: Option<bool>Whether Human Review feature should be skipped for this request. Default to false.